from setuptools import setup

setup(name='a_gb_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['a_gb_distributions'],
      author = "Ahmed Elshehawy",
      zip_safe=False)
